Stan Math Library: stan/math/fwd/scal/fun/primitive_value.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

primitive_value.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_PRIMITIVE_VALUE_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_PRIMITIVE_VALUE_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/primitive_value.hpp>
6
7 namespace stan {
8
9 namespace math {
10
11
21 template <typename T>
22 inline double primitive_value(const fvar<T>& v) {
23 using stan::math::primitive_value;
24 return primitive_value(v.val_);
25 }
26
27
28 }
29
30 }
31
32 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::primitive_value
double primitive_value(const fvar< T > &v)
Return the primitive value of the specified forward-mode autodiff variable.
Definition: primitive_value.hpp:22
primitive_value.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.